/*
   example1.c:  Check if a valid SmartDongle is plugged in.

   MicroWorks, Inc.
   2808 North Cole Road
   Boise, ID 83704

   www.smartdongle.com


   ***** BEGIN LICENSE BLOCK *****

   Version: MPL 1.1/GPL 2.0/LGPL 2.1

   The contents of this file are subject to the Mozilla Public License
   Version 1.1 (the "License"); you may not use this file except in
   compliance with the License. You may obtain a copy of the License at
   http://www.mozilla.org/MPL/

   Software distributed under the License is distributed on an "AS IS" basis,
   WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
   for the specific language governing rights and limitations under the
   License.

   The Original Code is MicroWorks, Inc. code.

   The Initial Developer of the Original Code is MicroWorks, Inc. Portions
   created by MicroWorks, Inc. are Copyright (C) 2006
   MicroWorks, Inc. All Rights Reserved.

   Contributor(s):

   Alternatively, the contents of this file may be used under the terms of
   either the GNU General Public License Version 2 or later (the "GPL"), or
   the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
   in which case the provisions of the GPL or the LGPL are applicable instead
   of those above. If you wish to allow use of your version of this file only
   under the terms of either the GPL or the LGPL, and not to allow others to
   use your version of this file under the terms of the MPL, indicate your
   decision by deleting the provisions above and replace them with the notice
   and other provisions required by the GPL or the LGPL. If you do not delete
   the provisions above, a recipient may use your version of this file under
   the terms of any one of the MPL, the GPL or the LGPL.

   ***** END LICENSE BLOCK *****
*/
#include <stdio.h>
#include <string.h>
#include "smartdongle.h"

int main ( int argc, char **argv) {

    int error;
    unsigned char data1[32];
    char errorString[200];
    unsigned long long challenge = -1;
    unsigned long long X;
    char* temp = "abcdefghij";
    int keyless = 0;

    /* SmartDongle demo keys. */
    unsigned long long P1 = 0xec6cc589aefd1e75ULL;
    unsigned long long P2 = 0xfcec0a6a82747b3fULL;

    if(keyless) {
        challenge = SmartDongleGetKeylessChallenge();
        X = challenge * P1 + P2;
        error = SmartDongleSendKeylessResponse(X);
        if(error == 0) {
            printf("Attempting write.\n");
            error = SmartDongleKeylessWrite(0, (unsigned char*)temp, 10);
        }

        if(error != 0)
            printf("SmartDongle write error!\n");
        else
            printf("SmartDongle write successful.\n");

        challenge = SmartDongleGetKeylessChallenge();
        X = challenge * P1 + P2;
        error = SmartDongleSendKeylessResponse(X);

        if(error == 0)
    	    error = SmartDongleKeylessRead(0, data1, 32);

        if (error) {
            SmartDongleGetErrorString(errorString, error);
            printf("FAIL: error %d, %s\n", error, errorString);
            return 1;
        }

        printf("SUCCESS: Valid SmartDongle present\n");
        printf("read: %s\n", data1);
        return 0;
    }
    else {
        error = SmartDongleRead(&P1, &P2, 0, NULL, 0);

        if (error) {
            SmartDongleGetErrorString(errorString, error);
            printf("FAIL: error %d, %s\n", error, errorString);
            return 1;
        }
        printf("SUCCESS: Valid SmartDongle present.\n");
        return 0;
    }
}
